@@ -1,10 +1,12 @@
 """PageRank analysis of graph structure. """
 from warnings import warn
+
 import networkx as nx
 
-__all__ = ["pagerank", "pagerank_numpy", "pagerank_scipy", "google_matrix"]
+__all__ = ["pagerank", "google_matrix"]
 
 
+@nx._dispatch
 def pagerank(
     G,
     alpha=0.85,
@@ -34,7 +36,7 @@ def pagerank(
       The "personalization vector" consisting of a dictionary with a
       key some subset of graph nodes and personalization value each of those.
       At least one personalization value must be non-zero.
-      If not specfiied, a nodes personalization value will be zero.
+      If not specified, a nodes personalization value will be zero.
       By default, a uniform distribution is used.
 
     max_iter : integer, optional
@@ -42,6 +44,7 @@ def pagerank(
 
     tol : float, optional
       Error tolerance used to check convergence in power method solver.
+      The iteration will stop after a tolerance of ``len(G) * tol`` is reached.
 
     nstart : dictionary, optional
       Starting value of PageRank iteration for each node.
@@ -85,7 +88,7 @@ def pagerank(
 
     See Also
     --------
-    pagerank_numpy, pagerank_scipy, google_matrix
+    google_matrix
 
     Raises
     ------
@@ -104,7 +107,7 @@ def pagerank(
        http://dbpubs.stanford.edu:8090/pub/showDoc.Fulltext?lang=en&doc=1999-66&format=pdf
 
     """
-    return pagerank_scipy(
+    return _pagerank_scipy(
         G, alpha, personalization, max_iter, tol, nstart, weight, dangling
     )
 
@@ -122,10 +125,7 @@ def _pagerank_python(
     if len(G) == 0:
         return {}
 
-    if not G.is_directed():
-        D = G.to_directed()
-    else:
-        D = G
+    D = G.to_directed()
 
     # Create a copy in (right) stochastic form
     W = nx.stochastic_graph(D, weight=weight)
@@ -136,21 +136,21 @@ def _pagerank_python(
         x = dict.fromkeys(W, 1.0 / N)
     else:
         # Normalized nstart vector
-        s = float(sum(nstart.values()))
+        s = sum(nstart.values())
         x = {k: v / s for k, v in nstart.items()}
 
     if personalization is None:
         # Assign uniform personalization vector if not given
         p = dict.fromkeys(W, 1.0 / N)
     else:
-        s = float(sum(personalization.values()))
+        s = sum(personalization.values())
         p = {k: v / s for k, v in personalization.items()}
 
     if dangling is None:
         # Use personalization vector if dangling vector not specified
         dangling_weights = p
     else:
-        s = float(sum(dangling.values()))
+        s = sum(dangling.values())
         dangling_weights = {k: v / s for k, v in dangling.items()}
     dangling_nodes = [n for n in W if W.out_degree(n, weight=weight) == 0.0]
 
@@ -166,12 +166,13 @@ def _pagerank_python(
                 x[nbr] += alpha * xlast[n] * wt
             x[n] += danglesum * dangling_weights.get(n, 0) + (1.0 - alpha) * p.get(n, 0)
         # check convergence, l1 norm
-        err = sum([abs(x[n] - xlast[n]) for n in x])
+        err = sum(abs(x[n] - xlast[n]) for n in x)
         if err < N * tol:
             return x
     raise nx.PowerIterationFailedConvergence(max_iter)
 
 
+@nx._dispatch
 def google_matrix(
     G, alpha=0.85, personalization=None, nodelist=None, weight="weight", dangling=None
 ):
@@ -190,7 +191,7 @@ def google_matrix(
       The "personalization vector" consisting of a dictionary with a
       key some subset of graph nodes and personalization value each of those.
       At least one personalization value must be non-zero.
-      If not specfiied, a nodes personalization value will be zero.
+      If not specified, a nodes personalization value will be zero.
       By default, a uniform distribution is used.
 
     nodelist : list, optional
@@ -211,12 +212,12 @@ def google_matrix(
 
     Returns
     -------
-    A : NumPy matrix
+    A : 2D NumPy ndarray
        Google matrix of the graph
 
     Notes
     -----
-    The matrix returned represents the transition matrix that describes the
+    The array returned represents the transition matrix that describes the
     Markov chain used in PageRank. For PageRank to converge to a unique
     solution (i.e., a unique stationary distribution in a Markov chain), the
     transition matrix must be irreducible. In other words, it must be that
@@ -229,17 +230,17 @@ def google_matrix(
 
     See Also
     --------
-    pagerank, pagerank_numpy, pagerank_scipy
+    pagerank
     """
     import numpy as np
 
     if nodelist is None:
         nodelist = list(G)
 
-    M = np.asmatrix(nx.to_numpy_array(G, nodelist=nodelist, weight=weight))
+    A = nx.to_numpy_array(G, nodelist=nodelist, weight=weight)
     N = len(G)
     if N == 0:
-        return M
+        return A
 
     # Personalization vector
     if personalization is None:
@@ -257,18 +258,19 @@ def google_matrix(
         # Convert the dangling dictionary into an array in nodelist order
         dangling_weights = np.array([dangling.get(n, 0) for n in nodelist], dtype=float)
         dangling_weights /= dangling_weights.sum()
-    dangling_nodes = np.where(M.sum(axis=1) == 0)[0]
+    dangling_nodes = np.where(A.sum(axis=1) == 0)[0]
 
     # Assign dangling_weights to any dangling nodes (nodes with no out links)
-    for node in dangling_nodes:
-        M[node] = dangling_weights
+    A[dangling_nodes] = dangling_weights
 
-    M /= M.sum(axis=1)  # Normalize rows to sum to 1
+    A /= A.sum(axis=1)[:, np.newaxis]  # Normalize rows to sum to 1
 
-    return alpha * M + (1 - alpha) * p
+    return alpha * A + (1 - alpha) * p
 
 
-def pagerank_numpy(G, alpha=0.85, personalization=None, weight="weight", dangling=None):
+def _pagerank_numpy(
+    G, alpha=0.85, personalization=None, weight="weight", dangling=None
+):
     """Returns the PageRank of the nodes in the graph.
 
     PageRank computes a ranking of the nodes in the graph G based on
@@ -288,7 +290,7 @@ def pagerank_numpy(G, alpha=0.85, personalization=None, weight="weight", danglin
       The "personalization vector" consisting of a dictionary with a
       key some subset of graph nodes and personalization value each of those.
       At least one personalization value must be non-zero.
-      If not specfiied, a nodes personalization value will be zero.
+      If not specified, a nodes personalization value will be zero.
       By default, a uniform distribution is used.
 
     weight : key, optional
@@ -310,8 +312,9 @@ def pagerank_numpy(G, alpha=0.85, personalization=None, weight="weight", danglin
 
     Examples
     --------
+    >>> from networkx.algorithms.link_analysis.pagerank_alg import _pagerank_numpy
     >>> G = nx.DiGraph(nx.path_graph(4))
-    >>> pr = nx.pagerank_numpy(G, alpha=0.9)
+    >>> pr = _pagerank_numpy(G, alpha=0.9)
 
     Notes
     -----
@@ -325,7 +328,7 @@ def pagerank_numpy(G, alpha=0.85, personalization=None, weight="weight", danglin
 
     See Also
     --------
-    pagerank, pagerank_scipy, google_matrix
+    pagerank, google_matrix
 
     References
     ----------
@@ -336,8 +339,6 @@ def pagerank_numpy(G, alpha=0.85, personalization=None, weight="weight", danglin
        The PageRank citation ranking: Bringing order to the Web. 1999
        http://dbpubs.stanford.edu:8090/pub/showDoc.Fulltext?lang=en&doc=1999-66&format=pdf
     """
-    msg = "networkx.pagerank_numpy is deprecated and will be removed in NetworkX 3.0, use networkx.pagerank instead."
-    warn(msg, DeprecationWarning, stacklevel=2)
     import numpy as np
 
     if len(G) == 0:
@@ -350,11 +351,11 @@ def pagerank_numpy(G, alpha=0.85, personalization=None, weight="weight", danglin
     ind = np.argmax(eigenvalues)
     # eigenvector of largest eigenvalue is at ind, normalized
     largest = np.array(eigenvectors[:, ind]).flatten().real
-    norm = float(largest.sum())
+    norm = largest.sum()
     return dict(zip(G, map(float, largest / norm)))
 
 
-def pagerank_scipy(
+def _pagerank_scipy(
     G,
     alpha=0.85,
     personalization=None,
@@ -383,7 +384,7 @@ def pagerank_scipy(
       The "personalization vector" consisting of a dictionary with a
       key some subset of graph nodes and personalization value each of those.
       At least one personalization value must be non-zero.
-      If not specfiied, a nodes personalization value will be zero.
+      If not specified, a nodes personalization value will be zero.
       By default, a uniform distribution is used.
 
     max_iter : integer, optional
@@ -391,6 +392,7 @@ def pagerank_scipy(
 
     tol : float, optional
       Error tolerance used to check convergence in power method solver.
+      The iteration will stop after a tolerance of ``len(G) * tol`` is reached.
 
     nstart : dictionary, optional
       Starting value of PageRank iteration for each node.
@@ -414,8 +416,9 @@ def pagerank_scipy(
 
     Examples
     --------
+    >>> from networkx.algorithms.link_analysis.pagerank_alg import _pagerank_scipy
     >>> G = nx.DiGraph(nx.path_graph(4))
-    >>> pr = nx.pagerank_scipy(G, alpha=0.9)
+    >>> pr = _pagerank_scipy(G, alpha=0.9)
 
     Notes
     -----
@@ -428,7 +431,7 @@ def pagerank_scipy(
 
     See Also
     --------
-    pagerank, pagerank_numpy, google_matrix
+    pagerank
 
     Raises
     ------
@@ -446,8 +449,6 @@ def pagerank_scipy(
        The PageRank citation ranking: Bringing order to the Web. 1999
        http://dbpubs.stanford.edu:8090/pub/showDoc.Fulltext?lang=en&doc=1999-66&format=pdf
     """
-    msg = "networkx.pagerank_scipy is deprecated and will be removed in NetworkX 3.0, use networkx.pagerank instead."
-    warn(msg, DeprecationWarning, stacklevel=2)
     import numpy as np
     import scipy as sp
     import scipy.sparse  # call as sp.sparse
@@ -457,18 +458,19 @@ def pagerank_scipy(
         return {}
 
     nodelist = list(G)
-    M = nx.to_scipy_sparse_matrix(G, nodelist=nodelist, weight=weight, dtype=float)
-    S = np.array(M.sum(axis=1)).flatten()
+    A = nx.to_scipy_sparse_array(G, nodelist=nodelist, weight=weight, dtype=float)
+    S = A.sum(axis=1)
     S[S != 0] = 1.0 / S[S != 0]
-    Q = sp.sparse.spdiags(S.T, 0, *M.shape, format="csr")
-    M = Q * M
+    # TODO: csr_array
+    Q = sp.sparse.csr_array(sp.sparse.spdiags(S.T, 0, *A.shape))
+    A = Q @ A
 
     # initial vector
     if nstart is None:
         x = np.repeat(1.0 / N, N)
     else:
         x = np.array([nstart.get(n, 0) for n in nodelist], dtype=float)
-        x = x / x.sum()
+        x /= x.sum()
 
     # Personalization vector
     if personalization is None:
@@ -477,7 +479,7 @@ def pagerank_scipy(
         p = np.array([personalization.get(n, 0) for n in nodelist], dtype=float)
         if p.sum() == 0:
             raise ZeroDivisionError
-        p = p / p.sum()
+        p /= p.sum()
     # Dangling nodes
     if dangling is None:
         dangling_weights = p
@@ -490,7 +492,7 @@ def pagerank_scipy(
     # power iteration: make up to max_iter iterations
     for _ in range(max_iter):
         xlast = x
-        x = alpha * (x * M + sum(x[is_dangling]) * dangling_weights) + (1 - alpha) * p
+        x = alpha * (x @ A + sum(x[is_dangling]) * dangling_weights) + (1 - alpha) * p
         # check convergence, l1 norm
         err = np.absolute(x - xlast).sum()
         if err < N * tol:
