@@ -26,17 +26,17 @@ This implementation is based on:
 #    pages={109-122},
 #    language={English}
 # }
-
-
 import string
+from dataclasses import dataclass, field
+from enum import Enum
 from operator import itemgetter
+from queue import PriorityQueue
 
 import networkx as nx
 from networkx.utils import py_random_state
 
 from .recognition import is_arborescence, is_branching
 
-
 __all__ = [
     "branching_weight",
     "greedy_branching",
@@ -44,6 +44,7 @@ __all__ = [
     "minimum_branching",
     "maximum_spanning_arborescence",
     "minimum_spanning_arborescence",
+    "ArborescenceIterator",
     "Edmonds",
 ]
 
@@ -75,6 +76,31 @@ def branching_weight(G, attr="weight", default=1):
     """
     Returns the total weight of a branching.
 
+    You must access this function through the networkx.algorithms.tree module.
+
+    Parameters
+    ----------
+    G : DiGraph
+        The directed graph.
+    attr : str
+        The attribute to use as weights. If None, then each edge will be
+        treated equally with a weight of 1.
+    default : float
+        When `attr` is not None, then if an edge does not have that attribute,
+        `default` specifies what value it should take.
+
+    Returns
+    -------
+    weight: int or float
+        The total weight of the branching.
+
+    Examples
+    --------
+    >>> G = nx.DiGraph()
+    >>> G.add_weighted_edges_from([(0, 1, 2), (1, 2, 4), (2, 3, 3), (3, 4, 2)])
+    >>> nx.tree.branching_weight(G)
+    11
+
     """
     return sum(edge[2].get(attr, default) for edge in G.edges(data=True))
 
@@ -220,8 +246,8 @@ class MultiDiGraph_EdgeKey(nx.MultiDiGraph):
     def remove_edge_with_key(self, key):
         try:
             u, v, _ = self.edge_index[key]
-        except KeyError as e:
-            raise KeyError(f"Invalid edge key {key!r}") from e
+        except KeyError as err:
+            raise KeyError(f"Invalid edge key {key!r}") from err
         else:
             del self.edge_index[key]
             self._cls.remove_edge(u, v, key)
@@ -239,6 +265,7 @@ def get_path(G, u, v):
 
     """
     nodes = nx.shortest_path(G, u, v)
+
     # We are guaranteed that there is only one edge connected every node
     # in the shortest path.
 
@@ -255,7 +282,23 @@ def get_path(G, u, v):
 
 class Edmonds:
     """
-    Edmonds algorithm for finding optimal branchings and spanning arborescences.
+    Edmonds algorithm [1]_ for finding optimal branchings and spanning
+    arborescences.
+
+    This algorithm can find both minimum and maximum spanning arborescences and
+    branchings.
+
+    Notes
+    -----
+    While this algorithm can find a minimum branching, since it isn't required
+    to be spanning, the minimum branching is always from the set of negative
+    weight edges which is most likely the empty set for most graphs.
+
+    References
+    ----------
+    .. [1] J. Edmonds, Optimum Branchings, Journal of Research of the National
+           Bureau of Standards, 1967, Vol. 71B, p.233-240,
+           https://archive.org/details/jresv71Bn4p233
 
     """
 
@@ -272,7 +315,7 @@ class Edmonds:
         # sure that our node names do not conflict with the real node names.
         self.template = random_string(seed=seed) + "_{0}"
 
-    def _init(self, attr, default, kind, style, preserve_attrs, seed):
+    def _init(self, attr, default, kind, style, preserve_attrs, seed, partition):
         if kind not in KINDS:
             raise nx.NetworkXException("Unknown value for `kind`.")
 
@@ -305,8 +348,11 @@ class Edmonds:
         for key, (u, v, data) in enumerate(self.G_original.edges(data=True)):
             d = {attr: trans(data.get(attr, default))}
 
+            if data.get(partition) is not None:
+                d[partition] = data.get(partition)
+
             if preserve_attrs:
-                for (d_k, d_v) in data.items():
+                for d_k, d_v in data.items():
                     if d_k != attr:
                         d[d_k] = d_v
 
@@ -330,11 +376,12 @@ class Edmonds:
         # A list of lists of edge indexes. Each list is a circuit for graph G^i.
         # Note the edge list will not, in general, be a circuit in graph G^0.
         self.circuits = []
-        # Stores the index of the minimum edge in the circuit found in G^i and B^i.
-        # The ordering of the edges seems to preserve the weight ordering from G^0.
-        # So even if the circuit does not form a circuit in G^0, it is still true
-        # that the minimum edge of the circuit in G^i is still the minimum edge
-        # in circuit G^0 (depsite their weights being different).
+        # Stores the index of the minimum edge in the circuit found in G^i
+        # and B^i. The ordering of the edges seems to preserve the weight
+        # ordering from G^0. So even if the circuit does not form a circuit
+        # in G^0, it is still true that the minimum edge of the circuit in
+        # G^i is still the minimum edge in circuit G^0 (despite their weights
+        # being different).
         self.minedge_circuit = []
 
     def find_optimum(
@@ -344,6 +391,7 @@ class Edmonds:
         kind="max",
         style="branching",
         preserve_attrs=False,
+        partition=None,
         seed=None,
     ):
         """
@@ -367,6 +415,9 @@ class Edmonds:
         preserve_attrs : bool
             If True, preserve the other edge attributes of the original
             graph (that are not the one passed to `attr`)
+        partition : str
+            The edge attribute holding edge partition data. Used in the
+            spanning arborescence iterator.
         seed : integer, random_state, or None (default)
             Indicator of random number generation state.
             See :ref:`Randomness<randomness>`.
@@ -377,7 +428,7 @@ class Edmonds:
             The branching.
 
         """
-        self._init(attr, default, kind, style, preserve_attrs, seed)
+        self._init(attr, default, kind, style, preserve_attrs, seed, partition)
         uf = self.uf
 
         # This enormous while loop could use some refactoring...
@@ -392,14 +443,27 @@ class Edmonds:
             """
             Find the edge directed toward v with maximal weight.
 
+            If an edge partition exists in this graph, return the included edge
+            if it exists and no not return any excluded edges. There can only
+            be one included edge for each vertex otherwise the edge partition is
+            empty.
             """
             edge = None
             weight = -INF
             for u, _, key, data in G.in_edges(v, data=True, keys=True):
+                # Skip excluded edges
+                if data.get(partition) == nx.EdgePartition.EXCLUDED:
+                    continue
                 new_weight = data[attr]
+                # Return the included edge
+                if data.get(partition) == nx.EdgePartition.INCLUDED:
+                    weight = new_weight
+                    edge = (u, v, key, new_weight, data)
+                    return edge, weight
+                # Find the best open edge
                 if new_weight > weight:
                     weight = new_weight
-                    edge = (u, v, key, new_weight)
+                    edge = (u, v, key, new_weight, data)
 
             return edge, weight
 
@@ -452,7 +516,7 @@ class Edmonds:
                     # from the paper does hold. We need to store the circuit
                     # for future reference.
                     Q_nodes, Q_edges = get_path(B, v, u)
-                    Q_edges.append(edge[2])
+                    Q_edges.append(edge[2])  # Edge key
                 else:
                     # Then B with the edge is still a branching and condition
                     # (a) from the paper does not hold.
@@ -468,6 +532,8 @@ class Edmonds:
                 # print(f"Edge is acceptable: {acceptable}")
                 if acceptable:
                     dd = {attr: weight}
+                    if edge[4].get(partition) is not None:
+                        dd[partition] = edge[4].get(partition)
                     B.add_edge(u, v, edge[2], **dd)
                     G[u][v][edge[2]][self.candidate_attr] = True
                     uf.union(u, v)
@@ -486,8 +552,12 @@ class Edmonds:
                         Q_incoming_weight = {}
                         for edge_key in Q_edges:
                             u, v, data = B.edge_index[edge_key]
+                            # We cannot remove an included edges, even if it is
+                            # the minimum edge in the circuit
                             w = data[attr]
                             Q_incoming_weight[v] = w
+                            if data.get(partition) == nx.EdgePartition.INCLUDED:
+                                continue
                             if w < minweight:
                                 minweight = w
                                 minedge = edge_key
@@ -628,7 +698,7 @@ class Edmonds:
             # Optionally, preserve the other edge attributes of the original
             # graph
             if preserve_attrs:
-                for (key, value) in d.items():
+                for key, value in d.items():
                     if key not in [self.attr, self.candidate_attr]:
                         dd[key] = value
 
@@ -638,26 +708,47 @@ class Edmonds:
         return H
 
 
-def maximum_branching(G, attr="weight", default=1, preserve_attrs=False):
+def maximum_branching(
+    G, attr="weight", default=1, preserve_attrs=False, partition=None
+):
     ed = Edmonds(G)
     B = ed.find_optimum(
-        attr, default, kind="max", style="branching", preserve_attrs=preserve_attrs
+        attr,
+        default,
+        kind="max",
+        style="branching",
+        preserve_attrs=preserve_attrs,
+        partition=partition,
     )
     return B
 
 
-def minimum_branching(G, attr="weight", default=1, preserve_attrs=False):
+def minimum_branching(
+    G, attr="weight", default=1, preserve_attrs=False, partition=None
+):
     ed = Edmonds(G)
     B = ed.find_optimum(
-        attr, default, kind="min", style="branching", preserve_attrs=preserve_attrs
+        attr,
+        default,
+        kind="min",
+        style="branching",
+        preserve_attrs=preserve_attrs,
+        partition=partition,
     )
     return B
 
 
-def maximum_spanning_arborescence(G, attr="weight", default=1, preserve_attrs=False):
+def maximum_spanning_arborescence(
+    G, attr="weight", default=1, preserve_attrs=False, partition=None
+):
     ed = Edmonds(G)
     B = ed.find_optimum(
-        attr, default, kind="max", style="arborescence", preserve_attrs=preserve_attrs
+        attr,
+        default,
+        kind="max",
+        style="arborescence",
+        preserve_attrs=preserve_attrs,
+        partition=partition,
     )
     if not is_arborescence(B):
         msg = "No maximum spanning arborescence in G."
@@ -665,10 +756,17 @@ def maximum_spanning_arborescence(G, attr="weight", default=1, preserve_attrs=Fa
     return B
 
 
-def minimum_spanning_arborescence(G, attr="weight", default=1, preserve_attrs=False):
+def minimum_spanning_arborescence(
+    G, attr="weight", default=1, preserve_attrs=False, partition=None
+):
     ed = Edmonds(G)
     B = ed.find_optimum(
-        attr, default, kind="min", style="arborescence", preserve_attrs=preserve_attrs
+        attr,
+        default,
+        kind="min",
+        style="arborescence",
+        preserve_attrs=preserve_attrs,
+        partition=partition,
     )
     if not is_arborescence(B):
         msg = "No minimum spanning arborescence in G."
@@ -691,6 +789,10 @@ default : float
 preserve_attrs : bool
     If True, preserve the other attributes of the original graph (that are not
     passed to `attr`)
+partition : str
+    The key for the edge attribute containing the partition
+    data on the graph. Edges can be included, excluded or open using the
+    `EdgePartition` enum.
 
 Returns
 -------
@@ -724,3 +826,223 @@ maximum_spanning_arborescence.__doc__ = docstring_arborescence.format(
 minimum_spanning_arborescence.__doc__ = docstring_arborescence.format(
     kind="minimum", style="spanning arborescence"
 )
+
+
+class ArborescenceIterator:
+    """
+    Iterate over all spanning arborescences of a graph in either increasing or
+    decreasing cost.
+
+    Notes
+    -----
+    This iterator uses the partition scheme from [1]_ (included edges,
+    excluded edges and open edges). It generates minimum spanning
+    arborescences using a modified Edmonds' Algorithm which respects the
+    partition of edges. For arborescences with the same weight, ties are
+    broken arbitrarily.
+
+    References
+    ----------
+    .. [1] G.K. Janssens, K. Sörensen, An algorithm to generate all spanning
+           trees in order of increasing cost, Pesquisa Operacional, 2005-08,
+           Vol. 25 (2), p. 219-229,
+           https://www.scielo.br/j/pope/a/XHswBwRwJyrfL88dmMwYNWp/?lang=en
+    """
+
+    @dataclass(order=True)
+    class Partition:
+        """
+        This dataclass represents a partition and stores a dict with the edge
+        data and the weight of the minimum spanning arborescence of the
+        partition dict.
+        """
+
+        mst_weight: float
+        partition_dict: dict = field(compare=False)
+
+        def __copy__(self):
+            return ArborescenceIterator.Partition(
+                self.mst_weight, self.partition_dict.copy()
+            )
+
+    def __init__(self, G, weight="weight", minimum=True, init_partition=None):
+        """
+        Initialize the iterator
+
+        Parameters
+        ----------
+        G : nx.DiGraph
+            The directed graph which we need to iterate trees over
+
+        weight : String, default = "weight"
+            The edge attribute used to store the weight of the edge
+
+        minimum : bool, default = True
+            Return the trees in increasing order while true and decreasing order
+            while false.
+
+        init_partition : tuple, default = None
+            In the case that certain edges have to be included or excluded from
+            the arborescences, `init_partition` should be in the form
+            `(included_edges, excluded_edges)` where each edges is a
+            `(u, v)`-tuple inside an iterable such as a list or set.
+
+        """
+        self.G = G.copy()
+        self.weight = weight
+        self.minimum = minimum
+        self.method = (
+            minimum_spanning_arborescence if minimum else maximum_spanning_arborescence
+        )
+        # Randomly create a key for an edge attribute to hold the partition data
+        self.partition_key = (
+            "ArborescenceIterators super secret partition attribute name"
+        )
+        if init_partition is not None:
+            partition_dict = {}
+            for e in init_partition[0]:
+                partition_dict[e] = nx.EdgePartition.INCLUDED
+            for e in init_partition[1]:
+                partition_dict[e] = nx.EdgePartition.EXCLUDED
+            self.init_partition = ArborescenceIterator.Partition(0, partition_dict)
+        else:
+            self.init_partition = None
+
+    def __iter__(self):
+        """
+        Returns
+        -------
+        ArborescenceIterator
+            The iterator object for this graph
+        """
+        self.partition_queue = PriorityQueue()
+        self._clear_partition(self.G)
+
+        # Write the initial partition if it exists.
+        if self.init_partition is not None:
+            self._write_partition(self.init_partition)
+
+        mst_weight = self.method(
+            self.G,
+            self.weight,
+            partition=self.partition_key,
+            preserve_attrs=True,
+        ).size(weight=self.weight)
+
+        self.partition_queue.put(
+            self.Partition(
+                mst_weight if self.minimum else -mst_weight,
+                {}
+                if self.init_partition is None
+                else self.init_partition.partition_dict,
+            )
+        )
+
+        return self
+
+    def __next__(self):
+        """
+        Returns
+        -------
+        (multi)Graph
+            The spanning tree of next greatest weight, which ties broken
+            arbitrarily.
+        """
+        if self.partition_queue.empty():
+            del self.G, self.partition_queue
+            raise StopIteration
+
+        partition = self.partition_queue.get()
+        self._write_partition(partition)
+        next_arborescence = self.method(
+            self.G,
+            self.weight,
+            partition=self.partition_key,
+            preserve_attrs=True,
+        )
+        self._partition(partition, next_arborescence)
+
+        self._clear_partition(next_arborescence)
+        return next_arborescence
+
+    def _partition(self, partition, partition_arborescence):
+        """
+        Create new partitions based of the minimum spanning tree of the
+        current minimum partition.
+
+        Parameters
+        ----------
+        partition : Partition
+            The Partition instance used to generate the current minimum spanning
+            tree.
+        partition_arborescence : nx.Graph
+            The minimum spanning arborescence of the input partition.
+        """
+        # create two new partitions with the data from the input partition dict
+        p1 = self.Partition(0, partition.partition_dict.copy())
+        p2 = self.Partition(0, partition.partition_dict.copy())
+        for e in partition_arborescence.edges:
+            # determine if the edge was open or included
+            if e not in partition.partition_dict:
+                # This is an open edge
+                p1.partition_dict[e] = nx.EdgePartition.EXCLUDED
+                p2.partition_dict[e] = nx.EdgePartition.INCLUDED
+
+                self._write_partition(p1)
+                try:
+                    p1_mst = self.method(
+                        self.G,
+                        self.weight,
+                        partition=self.partition_key,
+                        preserve_attrs=True,
+                    )
+
+                    p1_mst_weight = p1_mst.size(weight=self.weight)
+                    p1.mst_weight = p1_mst_weight if self.minimum else -p1_mst_weight
+                    self.partition_queue.put(p1.__copy__())
+                except nx.NetworkXException:
+                    pass
+
+                p1.partition_dict = p2.partition_dict.copy()
+
+    def _write_partition(self, partition):
+        """
+        Writes the desired partition into the graph to calculate the minimum
+        spanning tree. Also, if one incoming edge is included, mark all others
+        as excluded so that if that vertex is merged during Edmonds' algorithm
+        we cannot still pick another of that vertex's included edges.
+
+        Parameters
+        ----------
+        partition : Partition
+            A Partition dataclass describing a partition on the edges of the
+            graph.
+        """
+        for u, v, d in self.G.edges(data=True):
+            if (u, v) in partition.partition_dict:
+                d[self.partition_key] = partition.partition_dict[(u, v)]
+            else:
+                d[self.partition_key] = nx.EdgePartition.OPEN
+
+        for n in self.G:
+            included_count = 0
+            excluded_count = 0
+            for u, v, d in self.G.in_edges(nbunch=n, data=True):
+                if d.get(self.partition_key) == nx.EdgePartition.INCLUDED:
+                    included_count += 1
+                elif d.get(self.partition_key) == nx.EdgePartition.EXCLUDED:
+                    excluded_count += 1
+            # Check that if there is an included edges, all other incoming ones
+            # are excluded. If not fix it!
+            if included_count == 1 and excluded_count != self.G.in_degree(n) - 1:
+                for u, v, d in self.G.in_edges(nbunch=n, data=True):
+                    if d.get(self.partition_key) != nx.EdgePartition.INCLUDED:
+                        d[self.partition_key] = nx.EdgePartition.EXCLUDED
+
+    def _clear_partition(self, G):
+        """
+        Removes partition data from the graph
+        """
+        for u, v, d in G.edges(data=True):
+            if self.partition_key in d:
+                del d[self.partition_key]
