@@ -146,13 +146,13 @@ graph   [
     def test_parse_gml(self):
         G = nx.parse_gml(self.simple_data, label="label")
         assert sorted(G.nodes()) == ["Node 1", "Node 2", "Node 3"]
-        assert [e for e in sorted(G.edges())] == [
+        assert sorted(G.edges()) == [
             ("Node 1", "Node 2"),
             ("Node 2", "Node 3"),
             ("Node 3", "Node 1"),
         ]
 
-        assert [e for e in sorted(G.edges(data=True))] == [
+        assert sorted(G.edges(data=True)) == [
             (
                 "Node 1",
                 "Node 2",
@@ -446,14 +446,14 @@ graph
         G = nx.Graph()
         G.name = data
         G.graph["data"] = data
-        G.add_node(0, int=-1, data=dict(data=data))
+        G.add_node(0, int=-1, data={"data": data})
         G.add_edge(0, 0, float=-2.5, data=data)
         gml = "\n".join(nx.generate_gml(G, stringizer=literal_stringizer))
         G = nx.parse_gml(gml, destringizer=literal_destringizer)
         assert data == G.name
         assert {"name": data, "data": data} == G.graph
-        assert list(G.nodes(data=True)) == [(0, dict(int=-1, data=dict(data=data)))]
-        assert list(G.edges(data=True)) == [(0, 0, dict(float=-2.5, data=data))]
+        assert list(G.nodes(data=True)) == [(0, {"int": -1, "data": {"data": data}})]
+        assert list(G.edges(data=True)) == [(0, 0, {"float": -2.5, "data": data})]
         G = nx.Graph()
         G.graph["data"] = "frozenset([1, 2, 3])"
         G = nx.parse_gml(nx.generate_gml(G), destringizer=literal_eval)
@@ -544,7 +544,7 @@ graph
             "directed 1 multigraph 1 ]"
         )
 
-        # Tests for string convertable alphanumeric id and label values
+        # Tests for string convertible alphanumeric id and label values
         nx.parse_gml("graph [edge [ source a target a ] node [ id a label b ] ]")
         nx.parse_gml(
             "graph [ node [ id n42 label 0 ] node [ id x43 label 1 ]"
@@ -710,7 +710,7 @@ class TestPropertyLists:
         assert graph.nodes(data=True)["n1"] == {"properties": ["element"]}
 
 
-@pytest.mark.parametrize("coll", (list(), tuple()))
+@pytest.mark.parametrize("coll", ([], ()))
 def test_stringize_empty_list_tuple(coll):
     G = nx.path_graph(2)
     G.nodes[0]["test"] = coll  # test serializing an empty collection
